@@ -4,7 +4,7 @@ use Catmandu::Sane;
 use Lido::XML;
 use XML::LibXML::Reader;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Moo;
 use namespace::clean;
@@ -16,15 +16,24 @@ has 'lido'      => (is => 'lazy');
 sub _build_lido {
     return Lido::XML->new;
 }
- 
+
 sub generator {
     my ($self) = @_;
+    my $file = $self->file;
+    my %opts;
+
+    if (ref($file)) {
+        %opts = ('IO' , $file);
+    }
+    else {
+        %opts = ('location' , $file);
+    }
 
     sub {
-        state $reader = XML::LibXML::Reader->new(IO => $self->file);
+        state $reader = XML::LibXML::Reader->new(%opts);
 
         my $match = $reader->nextPatternMatch(
-            XML::LibXML::Pattern->new( 
+            XML::LibXML::Pattern->new(
                 '//lido:lido', { lido => 'http://www.lido-schema.org' }
             )
         );
@@ -49,7 +58,7 @@ __END__
 
 =head1 NAME
 
-Catmandu::Importer::LIDO - A LIDO XML importer 
+Catmandu::Importer::LIDO - A LIDO XML importer
 
 =head1 SYNOPSIS
 
@@ -68,7 +77,7 @@ Catmandu::Importer::LIDO - A LIDO XML importer
 
 =head1 DESCRIPTION
 
-This is a L<Catmandu::Importer> for converting LIDO data (an XML Schema for 
+This is a L<Catmandu::Importer> for converting LIDO data (an XML Schema for
 Contributing Content to Cultural Heritage Repositories).
 
 =head1 CONFIGURATION
@@ -108,4 +117,4 @@ inherited.
 
 L<Catmandu::Importer>, L<Lido::XML>
 
-=cut
\ No newline at end of file
+=cut
